==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Farchive_mail.0.9-1.4.2.tar.gz: archive_mail/includes/display_save.php <==
<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Archive Mail
    Version ........ 0.9
    Purpose ........ Allows you to download your email in a compressed archive

*******************************************************************************/

      global $username, $data_dir;
      global $archivefilenames, $archiveattachments, $archivetype;
      $hashed_dir = GetHashedDir($username, $data_dir);
      if (isset($_POST['archivefilenames'])) {
         $archivefilenames = $_POST['archivefilenames'];
         setPref($hashed_dir, $username, 'archivefilenames', $archivefilenames);
      }
      if (isset($_POST['archiveattachments'])) {
         $archiveattachments = $_POST['archiveattachments'];
         setPref($hashed_dir, $username, 'archiveattachments', $archiveattachments);
      }
      if (isset($_POST['archivetype'])) {
         $archivetype = $_POST['archivetype'];
         setPref($hashed_dir, $username, 'archivetype', $archivetype);
      }
      if (isset($_POST['archiveent'])) {
         $archiveent = $_POST['archiveent'];
         setPref($hashed_dir, $username, 'archiveent', $archiveent);

         if ($archiveent != 2) {
            $filename = getHashedFile($username, $data_dir, "$username.pref");
            $at = getPref($filename, $username, 'archivetype');
            if ($at == 2){
               $archivetype = 0;
               setPref($hashed_dir, $username, 'archivetype', $archivetype);
            }
         }
      }
?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Farchive_mail.1.0-1.4.2.tar.gz: archive_mail/includes/display_save.php <==
<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Archive Mail
    Version ........ 0.9
    Purpose ........ Allows you to download your email in a compressed archive

*******************************************************************************/

      global $username, $data_dir;
      global $archivefilenames, $archiveattachments, $archivetype;
      if (isset($_POST['archivefilenames'])) {
         $archivefilenames = $_POST['archivefilenames'];
         setPref($data_dir, $username, 'archivefilenames', $archivefilenames);
      }
      if (isset($_POST['archiveattachments'])) {
         $archiveattachments = $_POST['archiveattachments'];
         setPref($data_dir, $username, 'archiveattachments', $archiveattachments);
      }
      if (isset($_POST['archivetype'])) {
         $archivetype = $_POST['archivetype'];
         setPref($data_dir, $username, 'archivetype', $archivetype);
      }
      if (isset($_POST['archiveent'])) {
         $archiveent = $_POST['archiveent'];
         setPref($data_dir, $username, 'archiveent', $archiveent);

         if ($archiveent != 2) {
            $filename = getHashedFile($username, $data_dir, "$username.pref");
            $at = getPref($filename, $username, 'archivetype');
            if ($at == 2){
               $archivetype = 0;
               setPref($data_dir, $username, 'archivetype', $archivetype);
            }
         }
      }
?>
